@@ -125,15 +125,15 @@ fn e_opt_handle(success: bool) -> Option<u32> {
 }
 
 fn e_res_nb(success: bool) -> Result<(), lib::ExpectationFailed> {
-    e_res_handle(success).expect_result_nb("this error message should be displayed")
+    e_res_handle(success).expect_result_nb_("this error message should be displayed")
 }
 
 fn e_res(success: bool) -> Result<(), Box<dyn error::Error>> {
-    e_res_handle(success).expect_result("this error message should be displayed")
+    e_res_handle(success).expect_result_("this error message should be displayed")
 }
 
 fn e_opt_nb(success: bool) -> Result<(), lib::ExpectationFailed> {
-    let res = e_opt_handle(success).expect_result_nb("this error message should be displayed")?;
+    let res = e_opt_handle(success).expect_result_nb_("this error message should be displayed")?;
     if res != 0 {
         panic!("e_opt_handle() did not return 0");
     }
@@ -141,7 +141,7 @@ fn e_opt_nb(success: bool) -> Result<(), lib::ExpectationFailed> {
 }
 
 fn e_opt(success: bool) -> Result<(), Box<dyn error::Error>> {
-    let res = e_opt_handle(success).expect_result("this error message should be displayed")?;
+    let res = e_opt_handle(success).expect_result_("this error message should be displayed")?;
     if res != 0 {
         panic!("e_opt_handle() did not return 0");
     }
@@ -496,38 +496,38 @@ fn handle(mode: OpMode) {
     };
 
     match mode {
-        OpMode::RNUOk => return_ok().or_die_e("This should not be triggered"),
-        OpMode::RNUFail => return_err().or_die_e("This should be triggered"),
-        OpMode::RUOk => return_ok().or_exit_e("This should not be triggered"),
-        OpMode::RUFail => return_err().or_exit_e("This should be triggered"),
-        OpMode::RFNUOk => return_ok().or_die_e_f(cb),
-        OpMode::RFNUFail => return_err().or_die_e_f(cb),
-        OpMode::RFUOk => return_ok().or_exit_e_f(cb),
-        OpMode::RFUFail => return_err().or_exit_e_f(cb),
-        OpMode::ONUOk => o_return_some().or_die("This should not be triggered"),
-        OpMode::ONUFail => o_return_none().or_die("This should be triggered"),
-        OpMode::OUOk => o_return_some().or_exit("This should not be triggered"),
-        OpMode::OUFail => o_return_none().or_exit("This should be triggered"),
-        OpMode::OFNUOk => o_return_some().or_die_f(cb),
-        OpMode::OFNUFail => o_return_none().or_die_f(cb),
-        OpMode::OFUOk => o_return_some().or_exit_f(cb),
-        OpMode::OFUFail => o_return_none().or_exit_f(cb),
-        OpMode::RENBOk => e_res_nb(true).or_die_e("This should not be triggered"),
-        OpMode::RENBFail => e_res_nb(false).or_die_e("This should be triggered"),
-        OpMode::REBOk => e_res(true).or_die_e("This should not be triggered"),
-        OpMode::REBFail => e_res(false).or_die_e("This should be triggered"),
-        OpMode::REFNBOk => e_res_nb(true).or_die_e_f(cb),
-        OpMode::REFNBFail => e_res_nb(false).or_die_e_f(cb),
-        OpMode::REFBOk => e_res(true).or_die_e_f(cb),
-        OpMode::REFBFail => e_res(false).or_die_e_f(cb),
-        OpMode::OENBOk => e_opt_nb(true).or_die_e("This should not be triggered"),
-        OpMode::OENBFail => e_opt_nb(false).or_die_e("This should be triggered"),
-        OpMode::OEBOk => e_opt(true).or_die_e("This should not be triggered"),
-        OpMode::OEBFail => e_opt(false).or_die_e("This should be triggered"),
-        OpMode::OEFNBOk => e_opt_nb(true).or_die_e_f(cb),
-        OpMode::OEFNBFail => e_opt_nb(false).or_die_e_f(cb),
-        OpMode::OEFBOk => e_opt(true).or_die_e_f(cb),
-        OpMode::OEFBFail => e_opt(false).or_die_e_f(cb),
+        OpMode::RNUOk => return_ok().or_die_e_("This should not be triggered"),
+        OpMode::RNUFail => return_err().or_die_e_("This should be triggered"),
+        OpMode::RUOk => return_ok().or_exit_e_("This should not be triggered"),
+        OpMode::RUFail => return_err().or_exit_e_("This should be triggered"),
+        OpMode::RFNUOk => return_ok().or_die_e(cb),
+        OpMode::RFNUFail => return_err().or_die_e(cb),
+        OpMode::RFUOk => return_ok().or_exit_e(cb),
+        OpMode::RFUFail => return_err().or_exit_e(cb),
+        OpMode::ONUOk => o_return_some().or_die_("This should not be triggered"),
+        OpMode::ONUFail => o_return_none().or_die_("This should be triggered"),
+        OpMode::OUOk => o_return_some().or_exit_("This should not be triggered"),
+        OpMode::OUFail => o_return_none().or_exit_("This should be triggered"),
+        OpMode::OFNUOk => o_return_some().or_die(cb),
+        OpMode::OFNUFail => o_return_none().or_die(cb),
+        OpMode::OFUOk => o_return_some().or_exit(cb),
+        OpMode::OFUFail => o_return_none().or_exit(cb),
+        OpMode::RENBOk => e_res_nb(true).or_die_e_("This should not be triggered"),
+        OpMode::RENBFail => e_res_nb(false).or_die_e_("This should be triggered"),
+        OpMode::REBOk => e_res(true).or_die_e_("This should not be triggered"),
+        OpMode::REBFail => e_res(false).or_die_e_("This should be triggered"),
+        OpMode::REFNBOk => e_res_nb(true).or_die_e(cb),
+        OpMode::REFNBFail => e_res_nb(false).or_die_e(cb),
+        OpMode::REFBOk => e_res(true).or_die_e(cb),
+        OpMode::REFBFail => e_res(false).or_die_e(cb),
+        OpMode::OENBOk => e_opt_nb(true).or_die_e_("This should not be triggered"),
+        OpMode::OENBFail => e_opt_nb(false).or_die_e_("This should be triggered"),
+        OpMode::OEBOk => e_opt(true).or_die_e_("This should not be triggered"),
+        OpMode::OEBFail => e_opt(false).or_die_e_("This should be triggered"),
+        OpMode::OEFNBOk => e_opt_nb(true).or_die_e(cb),
+        OpMode::OEFNBFail => e_opt_nb(false).or_die_e(cb),
+        OpMode::OEFBOk => e_opt(true).or_die_e(cb),
+        OpMode::OEFBFail => e_opt(false).or_die_e(cb),
         _ => panic!("How did we get here with mode {:?}?", mode),
     };
 
